import {
  ApplicationIntegrationType,
  InteractionContextType,
  SlashCommandBuilder,
} from "discord.js";
import { errorHandler } from "../utils/errorHandler.js";
import type { Command } from "../interfaces/command.js";

/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */
export const log: Command = {
  data: new SlashCommandBuilder().
    setName("log").
    setDescription("Log a moderation action.").
    setContexts([
      InteractionContextType.BotDM,
      InteractionContextType.Guild,
      InteractionContextType.PrivateChannel,
    ]).
    setIntegrationTypes([ ApplicationIntegrationType.UserInstall ]).
    addStringOption((option) => {
      return option.
        setName("action").
        setDescription("The action to log.").
        setRequired(true).
        addChoices([
          { name: "Ban", value: "ban" },
          { name: "Kick", value: "kick" },
          { name: "Mute", value: "mute" },
          { name: "Warn", value: "warn" },
          { name: "Block", value: "block" },
          { name: "Suspend", value: "suspend" },
        ]);
    }).
    addStringOption((option) => {
      return option.
        setName("platform").
        setDescription("The platform to log the action on.").
        setRequired(true).
        addChoices([
          { name: "Discord", value: "discord" },
          { name: "Twitch", value: "twitch" },
          { name: "Codeberg", value: "codeberg" },
          { name: "Bluesky", value: "bluesky" },
          { name: "Forum", value: "forum" },
          { name: "Reddit", value: "reddit" },
          { name: "IRC", value: "irc" },
          { name: "Slack", value: "slack" },
          { name: "Mastodon", value: "mastodon" },
          { name: "Twitter", value: "twitter" },
          { name: "GitHub", value: "github" },
          { name: "LinkedIn", value: "linkedin" },
          { name: "Peerlist", value: "peerlist" },
          { name: "Signal", value: "signal" },
          { name: "WhatsApp", value: "whatsapp" },
          { name: "Snapchat", value: "snapchat" },
        ]);
    }).
    addStringOption((option) => {
      return option.
        setName("username").
        setDescription("Username or UUID of the targeted user.").
        setRequired(true);
    }).
    addStringOption((option) => {
      return option.
        setName("reason").
        setDescription("Reason for the action.").
        setRequired(true);
    }),
  run: async(app, interaction) => {
    try {
      await interaction.deferReply({ ephemeral: true });
      if (interaction.user.id !== "465650873650118659") {
        await interaction.editReply({
          content:
            // eslint-disable-next-line stylistic/max-len -- This is a single string.
            "Only Naomi can use this app. Sorry! Feel free to join our Discord? https://chat.nhcarrigan.com",
        });
        return;
      }

      const action = interaction.options.getString("action", true);
      const platform = interaction.options.getString("platform", true);
      const uuid = interaction.options.getString("username", true);
      const reason = interaction.options.getString("reason", true);

      const number = await app.database.sanctions.count() + 1;
      await app.database.sanctions.create({
        data: {
          action,
          number,
          platform,
          reason,
          uuid,
        },
      });
      await interaction.editReply({
        content: `Logged ${action} #${String(
          number,
        )} on ${platform} for user ${uuid}.`,
      });
    } catch (error) {
      await errorHandler("log command", error);
      await interaction.editReply({
        content:
          "An error occurred while processing your command. Please try again.",
      });
    }
  },
};
