/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */
import {
  ApplicationIntegrationType,
  InteractionContextType,
  SlashCommandBuilder,
} from "discord.js";
import { errorHandler } from "../utils/errorHandler.js";
import type { Command } from "../interfaces/command.js";

export const revoke: Command = {
  data: new SlashCommandBuilder().
    setName("revoke").
    setDescription("Revoke a moderation action.").
    setContexts([
      InteractionContextType.BotDM,
      InteractionContextType.Guild,
      InteractionContextType.PrivateChannel,
    ]).
    setIntegrationTypes([ ApplicationIntegrationType.UserInstall ]).
    addIntegerOption((option) => {
      return option.
        setName("case").
        setDescription("The case number to revoke.").
        setRequired(true);
    }).
    addStringOption((option) => {
      return option.
        setName("reason").
        setDescription("The reason for revoking the case.").
        setRequired(true);
    }),
  run: async(app, interaction) => {
    try {
      await interaction.deferReply({ ephemeral: true });
      if (interaction.user.id !== "465650873650118659") {
        await interaction.editReply({
          content:
            // eslint-disable-next-line stylistic/max-len -- This is a single string.
            "Only Naomi can use this app. Sorry! Feel free to join our Discord? https://chat.nhcarrigan.com",
        });
        return;
      }

      const number = interaction.options.getInteger("case", true);
      const reason = interaction.options.getString("reason", true);

      const exists = await app.database.sanctions.findUnique({
        where: { number },
      });

      if (!exists) {
        await interaction.editReply({
          content: `Case ${String(number)} does not exist.`,
        });
        return;
      }

      await app.database.sanctions.update({
        data: {
          revokeDate:   new Date(),
          revokeReason: reason,
          revoked:      true,
        },
        where: {
          number,
        },
      });

      await interaction.editReply({
        content: `Revoked action ${String(number)} for ${reason}.`,
      });
    } catch (error) {
      await errorHandler("log command", error);
      await interaction.editReply({
        content:
          "An error occurred while processing your command. Please try again.",
      });
    }
  },
};
